@@ -5,12 +5,13 @@ use lemmy_api_common::{
   community::{CommunityResponse, EditCommunity},
   get_local_user_view_from_jwt,
 };
-use lemmy_apub::activities::community::update::UpdateCommunity;
-use lemmy_db_queries::{diesel_option_overwrite_to_url, Crud};
+use lemmy_apub::protocol::activities::community::update::UpdateCommunity;
 use lemmy_db_schema::{
+  diesel_option_overwrite_to_url,
   naive_now,
+  newtypes::PersonId,
   source::community::{Community, CommunityForm},
-  PersonId,
+  traits::Crud,
 };
 use lemmy_db_views_actor::community_moderator_view::CommunityModeratorView;
 use lemmy_utils::{utils::check_slurs_opt, ApiError, ConnectionId, LemmyError};
@@ -26,10 +27,11 @@ impl PerformCrud for EditCommunity {
     websocket_id: Option<ConnectionId>,
   ) -> Result<CommunityResponse, LemmyError> {
     let data: &EditCommunity = self;
-    let local_user_view = get_local_user_view_from_jwt(&data.auth, context.pool()).await?;
+    let local_user_view =
+      get_local_user_view_from_jwt(&data.auth, context.pool(), context.secret()).await?;
 
-    check_slurs_opt(&data.title)?;
-    check_slurs_opt(&data.description)?;
+    check_slurs_opt(&data.title, &context.settings().slur_regex())?;
+    check_slurs_opt(&data.description, &context.settings().slur_regex())?;
 
     // Verify its a mod (only mods can edit it)
     let community_id = data.community_id;
@@ -39,7 +41,7 @@ impl PerformCrud for EditCommunity {
     })
     .await??;
     if !mods.contains(&local_user_view.person.id) {
-      return Err(ApiError::err("not_a_moderator").into());
+      return Err(ApiError::err_plain("not_a_moderator").into());
     }
 
     let community_id = data.community_id;
@@ -67,9 +69,14 @@ impl PerformCrud for EditCommunity {
       Community::update(conn, community_id, &community_form)
     })
     .await?
-    .map_err(|_| ApiError::err("couldnt_update_community"))?;
+    .map_err(|e| ApiError::err("couldnt_update_community", e))?;
 
-    UpdateCommunity::send(&updated_community, &local_user_view.person, context).await?;
+    UpdateCommunity::send(
+      updated_community.into(),
+      &local_user_view.person.into(),
+      context,
+    )
+    .await?;
 
     let op = UserOperationCrud::EditCommunity;
     send_community_ws_message(data.community_id, op, websocket_id, None, context).await
